@@ -12,12 +12,12 @@ GType cut_test_result_status_get_type (void);
 #define CUT_TYPE_TEST_RESULT_STATUS (cut_test_result_status_get_type())
 GType cut_order_get_type (void);
 #define CUT_TYPE_ORDER (cut_order_get_type())
-GType cut_report_file_mode_get_type (void);
-#define CUT_TYPE_REPORT_FILE_MODE (cut_report_file_mode_get_type())
 GType cut_verbose_level_get_type (void);
 #define CUT_TYPE_VERBOSE_LEVEL (cut_verbose_level_get_type())
 GType cut_verbose_level_error_get_type (void);
 #define CUT_TYPE_VERBOSE_LEVEL_ERROR (cut_verbose_level_error_get_type())
+GType cut_sequence_match_operation_type_get_type (void);
+#define CUT_TYPE_SEQUENCE_MATCH_OPERATION_TYPE (cut_sequence_match_operation_type_get_type())
 G_END_DECLS
 
 #endif /* __CUT_ENUM_TYPES_H__ */
