@@ -654,6 +654,9 @@ dispose (GObject *object)
     g_free(priv->source_directory);
     priv->source_directory = NULL;
 
+    g_free(priv->test_directory);
+    priv->test_directory = NULL;
+
     g_strfreev(priv->exclude_files);
     priv->exclude_files = NULL;
 
@@ -785,10 +788,13 @@ get_property (GObject    *object,
         break;
       case PROP_TEST_DIRECTORY:
         g_value_set_string(value, priv->test_directory);
+        break;
       case PROP_SOURCE_DIRECTORY:
         g_value_set_string(value, priv->source_directory);
+        break;
       case PROP_TARGET_TEST_CASE_NAMES:
         g_value_set_pointer(value, priv->target_test_case_names);
+        break;
       case PROP_TARGET_TEST_NAMES:
         g_value_set_pointer(value, priv->target_test_names);
         break;
@@ -910,9 +916,9 @@ pending_test (CutRunContext   *context,
 
 static void
 notification_test (CutRunContext   *context,
-              CutTest         *test,
-              CutTestContext  *test_context,
-              CutTestResult   *result)
+                   CutTest         *test,
+                   CutTestContext  *test_context,
+                   CutTestResult   *result)
 {
     CutRunContextPrivate *priv;
 
@@ -963,7 +969,8 @@ crashed (CutRunContext *context, const gchar *backtrace)
 }
 
 void
-cut_run_context_set_test_directory (CutRunContext *context, const gchar *directory)
+cut_run_context_set_test_directory (CutRunContext *context,
+                                    const gchar *directory)
 {
     CutRunContextPrivate *priv = CUT_RUN_CONTEXT_GET_PRIVATE(context);
 
@@ -978,7 +985,8 @@ cut_run_context_get_test_directory (CutRunContext *context)
 }
 
 void
-cut_run_context_set_source_directory (CutRunContext *context, const gchar *directory)
+cut_run_context_set_source_directory (CutRunContext *context,
+                                      const gchar *directory)
 {
     CutRunContextPrivate *priv = CUT_RUN_CONTEXT_GET_PRIVATE(context);
 
@@ -993,7 +1001,8 @@ cut_run_context_get_source_directory (CutRunContext *context)
 }
 
 void
-cut_run_context_set_multi_thread (CutRunContext *context, gboolean use_multi_thread)
+cut_run_context_set_multi_thread (CutRunContext *context,
+                                  gboolean use_multi_thread)
 {
     CutRunContextPrivate *priv = CUT_RUN_CONTEXT_GET_PRIVATE(context);
 
@@ -1050,7 +1059,8 @@ cut_run_context_get_exclude_directories (CutRunContext *context)
 }
 
 void
-cut_run_context_set_target_test_case_names (CutRunContext *context, gchar **names)
+cut_run_context_set_target_test_case_names (CutRunContext *context,
+                                            gchar **names)
 {
     CutRunContextPrivate *priv = CUT_RUN_CONTEXT_GET_PRIVATE(context);
 
@@ -1240,11 +1250,14 @@ cut_run_context_create_test_suite (CutRunContext *context)
     CutRunContextPrivate *priv;
     CutRepository *repository;
     CutTestSuite *suite;
+    const gchar **exclude_files, **exclude_directories;
 
     priv = CUT_RUN_CONTEXT_GET_PRIVATE(context);
     repository = cut_repository_new(priv->test_directory);
-    cut_repository_set_exclude_files(repository, (const gchar **)priv->exclude_files);
-    cut_repository_set_exclude_directories(repository, (const gchar **)priv->exclude_directories);
+    exclude_files = (const gchar **)priv->exclude_files;
+    cut_repository_set_exclude_files(repository, exclude_files);
+    exclude_directories = (const gchar **)priv->exclude_directories;
+    cut_repository_set_exclude_directories(repository, exclude_directories);
     suite = cut_repository_create_test_suite(repository);
     g_object_unref(repository);
 
@@ -1323,7 +1336,8 @@ cut_run_context_detach_listeners (CutRunContext *context)
 }
 
 gchar *
-cut_run_context_build_source_filename (CutRunContext *context, const gchar *filename)
+cut_run_context_build_source_filename (CutRunContext *context,
+                                       const gchar *filename)
 {
     const gchar *source_directory;
     gchar *source_filename;
